#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ONE_ELSE_ZERO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ONE_ELSE_ZERO_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/scalar/if_one_else_zero.hpp>

#endif
